==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksSelfLifecycleAndAuthorize.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectActivateLink;
import com.okta.sdk.resource.model.HrefObjectAuthorizeLink;
import com.okta.sdk.resource.model.HrefObjectDeactivateLink;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksSelfLifecycleAndAuthorize
 */
@JsonPropertyOrder({ LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_SELF,
        LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_ACTIVATE, LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_DEACTIVATE,
        LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_AUTHORIZE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksSelfLifecycleAndAuthorize implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_ACTIVATE = "activate";
    private HrefObjectActivateLink activate;

    public static final String JSON_PROPERTY_DEACTIVATE = "deactivate";
    private HrefObjectDeactivateLink deactivate;

    public static final String JSON_PROPERTY_AUTHORIZE = "authorize";
    private HrefObjectAuthorizeLink authorize;

    public LinksSelfLifecycleAndAuthorize() {
    }

    public LinksSelfLifecycleAndAuthorize self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public LinksSelfLifecycleAndAuthorize activate(HrefObjectActivateLink activate) {

        this.activate = activate;
        return this;
    }

    /**
     * Get activate
     *
     * @return activate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectActivateLink getActivate() {
        return activate;
    }

    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setActivate(HrefObjectActivateLink activate) {
        this.activate = activate;
    }

    public LinksSelfLifecycleAndAuthorize deactivate(HrefObjectDeactivateLink deactivate) {

        this.deactivate = deactivate;
        return this;
    }

    /**
     * Get deactivate
     *
     * @return deactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectDeactivateLink getDeactivate() {
        return deactivate;
    }

    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDeactivate(HrefObjectDeactivateLink deactivate) {
        this.deactivate = deactivate;
    }

    public LinksSelfLifecycleAndAuthorize authorize(HrefObjectAuthorizeLink authorize) {

        this.authorize = authorize;
        return this;
    }

    /**
     * Get authorize
     *
     * @return authorize
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTHORIZE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectAuthorizeLink getAuthorize() {
        return authorize;
    }

    @JsonProperty(JSON_PROPERTY_AUTHORIZE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthorize(HrefObjectAuthorizeLink authorize) {
        this.authorize = authorize;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksSelfLifecycleAndAuthorize linksSelfLifecycleAndAuthorize = (LinksSelfLifecycleAndAuthorize) o;
        return Objects.equals(this.self, linksSelfLifecycleAndAuthorize.self)
                && Objects.equals(this.activate, linksSelfLifecycleAndAuthorize.activate)
                && Objects.equals(this.deactivate, linksSelfLifecycleAndAuthorize.deactivate)
                && Objects.equals(this.authorize, linksSelfLifecycleAndAuthorize.authorize);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, activate, deactivate, authorize);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksSelfLifecycleAndAuthorize {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    activate: ").append(toIndentedString(activate)).append("\n");
        sb.append("    deactivate: ").append(toIndentedString(deactivate)).append("\n");
        sb.append("    authorize: ").append(toIndentedString(authorize)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksSelfLifecycleAndAuthorize.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectActivateLink;
import com.okta.sdk.resource.model.HrefObjectAuthorizeLink;
import com.okta.sdk.resource.model.HrefObjectDeactivateLink;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksSelfLifecycleAndAuthorize
 */
@JsonPropertyOrder({ LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_SELF,
        LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_ACTIVATE, LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_DEACTIVATE,
        LinksSelfLifecycleAndAuthorize.JSON_PROPERTY_AUTHORIZE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksSelfLifecycleAndAuthorize implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_ACTIVATE = "activate";
    private HrefObjectActivateLink activate;

    public static final String JSON_PROPERTY_DEACTIVATE = "deactivate";
    private HrefObjectDeactivateLink deactivate;

    public static final String JSON_PROPERTY_AUTHORIZE = "authorize";
    private HrefObjectAuthorizeLink authorize;

    public LinksSelfLifecycleAndAuthorize() {
    }

    public LinksSelfLifecycleAndAuthorize self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public LinksSelfLifecycleAndAuthorize activate(HrefObjectActivateLink activate) {

        this.activate = activate;
        return this;
    }

    /**
     * Get activate
     *
     * @return activate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectActivateLink getActivate() {
        return activate;
    }

    @JsonProperty(JSON_PROPERTY_ACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setActivate(HrefObjectActivateLink activate) {
        this.activate = activate;
    }

    public LinksSelfLifecycleAndAuthorize deactivate(HrefObjectDeactivateLink deactivate) {

        this.deactivate = deactivate;
        return this;
    }

    /**
     * Get deactivate
     *
     * @return deactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectDeactivateLink getDeactivate() {
        return deactivate;
    }

    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDeactivate(HrefObjectDeactivateLink deactivate) {
        this.deactivate = deactivate;
    }

    public LinksSelfLifecycleAndAuthorize authorize(HrefObjectAuthorizeLink authorize) {

        this.authorize = authorize;
        return this;
    }

    /**
     * Get authorize
     *
     * @return authorize
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTHORIZE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectAuthorizeLink getAuthorize() {
        return authorize;
    }

    @JsonProperty(JSON_PROPERTY_AUTHORIZE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthorize(HrefObjectAuthorizeLink authorize) {
        this.authorize = authorize;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksSelfLifecycleAndAuthorize linksSelfLifecycleAndAuthorize = (LinksSelfLifecycleAndAuthorize) o;
        return Objects.equals(this.self, linksSelfLifecycleAndAuthorize.self)
                && Objects.equals(this.activate, linksSelfLifecycleAndAuthorize.activate)
                && Objects.equals(this.deactivate, linksSelfLifecycleAndAuthorize.deactivate)
                && Objects.equals(this.authorize, linksSelfLifecycleAndAuthorize.authorize);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, activate, deactivate, authorize);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksSelfLifecycleAndAuthorize {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    activate: ").append(toIndentedString(activate)).append("\n");
        sb.append("    deactivate: ").append(toIndentedString(deactivate)).append("\n");
        sb.append("    authorize: ").append(toIndentedString(authorize)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
